==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/HTTPChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPChaosSpecFluent<A extends HTTPChaosSpecFluent<A>> extends BaseFluent<A>{
  public HTTPChaosSpecFluent() {
  }
  
  public HTTPChaosSpecFluent(HTTPChaosSpec instance) {
    this.copyInstance(instance);
  }
  private Boolean abort;
  private Integer code;
  private String delay;
  private String duration;
  private String method;
  private String mode;
  private PodHttpChaosPatchActionsBuilder patch;
  private String path;
  private Integer port;
  private PodHttpChaosReplaceActionsBuilder replace;
  private Map<String,String> requestHeaders;
  private Map<String,String> responseHeaders;
  private PodSelectorSpecBuilder selector;
  private String target;
  private String value;
  
  protected void copyInstance(HTTPChaosSpec instance) {
    instance = (instance != null ? instance : new HTTPChaosSpec());
  
    if (instance != null) {
        this.withAbort(instance.getAbort());
        this.withCode(instance.getCode());
        this.withDelay(instance.getDelay());
        this.withDuration(instance.getDuration());
        this.withMethod(instance.getMethod());
        this.withMode(instance.getMode());
        this.withPatch(instance.getPatch());
        this.withPath(instance.getPath());
        this.withPort(instance.getPort());
        this.withReplace(instance.getReplace());
        this.withRequestHeaders(instance.getRequestHeaders());
        this.withResponseHeaders(instance.getResponseHeaders());
        this.withSelector(instance.getSelector());
        this.withTarget(instance.getTarget());
        this.withValue(instance.getValue());
        this.withAbort(instance.getAbort());
        this.withCode(instance.getCode());
        this.withDelay(instance.getDelay());
        this.withDuration(instance.getDuration());
        this.withMethod(instance.getMethod());
        this.withMode(instance.getMode());
        this.withPatch(instance.getPatch());
        this.withPath(instance.getPath());
        this.withPort(instance.getPort());
        this.withReplace(instance.getReplace());
        this.withRequestHeaders(instance.getRequestHeaders());
        this.withResponseHeaders(instance.getResponseHeaders());
        this.withSelector(instance.getSelector());
        this.withTarget(instance.getTarget());
        this.withValue(instance.getValue());
      }
  }
  
  public Boolean getAbort() {
    return this.abort;
  }
  
  public A withAbort(Boolean abort) {
    this.abort=abort; return (A) this;
  }
  
  public boolean hasAbort() {
    return this.abort != null;
  }
  
  public Integer getCode() {
    return this.code;
  }
  
  public A withCode(Integer code) {
    this.code=code; return (A) this;
  }
  
  public boolean hasCode() {
    return this.code != null;
  }
  
  public String getDelay() {
    return this.delay;
  }
  
  public A withDelay(String delay) {
    this.delay=delay; return (A) this;
  }
  
  public boolean hasDelay() {
    return this.delay != null;
  }
  
  public String getDuration() {
    return this.duration;
  }
  
  public A withDuration(String duration) {
    this.duration=duration; return (A) this;
  }
  
  public boolean hasDuration() {
    return this.duration != null;
  }
  
  public String getMethod() {
    return this.method;
  }
  
  public A withMethod(String method) {
    this.method=method; return (A) this;
  }
  
  public boolean hasMethod() {
    return this.method != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode=mode; return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public PodHttpChaosPatchActions buildPatch() {
    return this.patch!=null ?this.patch.build():null;
  }
  
  public A withPatch(PodHttpChaosPatchActions patch) {
    _visitables.get("patch").remove(this.patch);
    if (patch!=null){ this.patch= new PodHttpChaosPatchActionsBuilder(patch); _visitables.get("patch").add(this.patch);} else { this.patch = null; _visitables.get("patch").remove(this.patch); } return (A) this;
  }
  
  public boolean hasPatch() {
    return this.patch != null;
  }
  
  public PatchNested<A> withNewPatch() {
    return new PatchNested(null);
  }
  
  public PatchNested<A> withNewPatchLike(PodHttpChaosPatchActions item) {
    return new PatchNested(item);
  }
  
  public PatchNested<A> editPatch() {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(null));
  }
  
  public PatchNested<A> editOrNewPatch() {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(new PodHttpChaosPatchActionsBuilder().build()));
  }
  
  public PatchNested<A> editOrNewPatchLike(PodHttpChaosPatchActions item) {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(item));
  }
  
  public String getPath() {
    return this.path;
  }
  
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  
  public boolean hasPath() {
    return this.path != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public PodHttpChaosReplaceActions buildReplace() {
    return this.replace!=null ?this.replace.build():null;
  }
  
  public A withReplace(PodHttpChaosReplaceActions replace) {
    _visitables.get("replace").remove(this.replace);
    if (replace!=null){ this.replace= new PodHttpChaosReplaceActionsBuilder(replace); _visitables.get("replace").add(this.replace);} else { this.replace = null; _visitables.get("replace").remove(this.replace); } return (A) this;
  }
  
  public boolean hasReplace() {
    return this.replace != null;
  }
  
  public ReplaceNested<A> withNewReplace() {
    return new ReplaceNested(null);
  }
  
  public ReplaceNested<A> withNewReplaceLike(PodHttpChaosReplaceActions item) {
    return new ReplaceNested(item);
  }
  
  public ReplaceNested<A> editReplace() {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(null));
  }
  
  public ReplaceNested<A> editOrNewReplace() {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(new PodHttpChaosReplaceActionsBuilder().build()));
  }
  
  public ReplaceNested<A> editOrNewReplaceLike(PodHttpChaosReplaceActions item) {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(item));
  }
  
  public A addToRequestHeaders(String key,String value) {
    if(this.requestHeaders == null && key != null && value != null) { this.requestHeaders = new LinkedHashMap(); }
    if(key != null && value != null) {this.requestHeaders.put(key, value);} return (A)this;
  }
  
  public A addToRequestHeaders(Map<String,String> map) {
    if(this.requestHeaders == null && map != null) { this.requestHeaders = new LinkedHashMap(); }
    if(map != null) { this.requestHeaders.putAll(map);} return (A)this;
  }
  
  public A removeFromRequestHeaders(String key) {
    if(this.requestHeaders == null) { return (A) this; }
    if(key != null && this.requestHeaders != null) {this.requestHeaders.remove(key);} return (A)this;
  }
  
  public A removeFromRequestHeaders(Map<String,String> map) {
    if(this.requestHeaders == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.requestHeaders != null){this.requestHeaders.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getRequestHeaders() {
    return this.requestHeaders;
  }
  
  public <K,V>A withRequestHeaders(Map<String,String> requestHeaders) {
    if (requestHeaders == null) { this.requestHeaders =  null;} else {this.requestHeaders = new LinkedHashMap(requestHeaders);} return (A) this;
  }
  
  public boolean hasRequestHeaders() {
    return this.requestHeaders != null;
  }
  
  public A addToResponseHeaders(String key,String value) {
    if(this.responseHeaders == null && key != null && value != null) { this.responseHeaders = new LinkedHashMap(); }
    if(key != null && value != null) {this.responseHeaders.put(key, value);} return (A)this;
  }
  
  public A addToResponseHeaders(Map<String,String> map) {
    if(this.responseHeaders == null && map != null) { this.responseHeaders = new LinkedHashMap(); }
    if(map != null) { this.responseHeaders.putAll(map);} return (A)this;
  }
  
  public A removeFromResponseHeaders(String key) {
    if(this.responseHeaders == null) { return (A) this; }
    if(key != null && this.responseHeaders != null) {this.responseHeaders.remove(key);} return (A)this;
  }
  
  public A removeFromResponseHeaders(Map<String,String> map) {
    if(this.responseHeaders == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.responseHeaders != null){this.responseHeaders.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getResponseHeaders() {
    return this.responseHeaders;
  }
  
  public <K,V>A withResponseHeaders(Map<String,String> responseHeaders) {
    if (responseHeaders == null) { this.responseHeaders =  null;} else {this.responseHeaders = new LinkedHashMap(responseHeaders);} return (A) this;
  }
  
  public boolean hasResponseHeaders() {
    return this.responseHeaders != null;
  }
  
  public PodSelectorSpec buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  
  public A withSelector(PodSelectorSpec selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new PodSelectorSpecBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  
  public boolean hasSelector() {
    return this.selector != null;
  }
  
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  
  public SelectorNested<A> withNewSelectorLike(PodSelectorSpec item) {
    return new SelectorNested(item);
  }
  
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodSelectorSpecBuilder().build()));
  }
  
  public SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  
  public String getTarget() {
    return this.target;
  }
  
  public A withTarget(String target) {
    this.target=target; return (A) this;
  }
  
  public boolean hasTarget() {
    return this.target != null;
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPChaosSpecFluent that = (HTTPChaosSpecFluent) o;
    if (!java.util.Objects.equals(abort, that.abort)) return false;
  
    if (!java.util.Objects.equals(code, that.code)) return false;
  
    if (!java.util.Objects.equals(delay, that.delay)) return false;
  
    if (!java.util.Objects.equals(duration, that.duration)) return false;
  
    if (!java.util.Objects.equals(method, that.method)) return false;
  
    if (!java.util.Objects.equals(mode, that.mode)) return false;
  
    if (!java.util.Objects.equals(patch, that.patch)) return false;
  
    if (!java.util.Objects.equals(path, that.path)) return false;
  
    if (!java.util.Objects.equals(port, that.port)) return false;
  
    if (!java.util.Objects.equals(replace, that.replace)) return false;
  
    if (!java.util.Objects.equals(requestHeaders, that.requestHeaders)) return false;
  
    if (!java.util.Objects.equals(responseHeaders, that.responseHeaders)) return false;
  
    if (!java.util.Objects.equals(selector, that.selector)) return false;
  
    if (!java.util.Objects.equals(target, that.target)) return false;
  
    if (!java.util.Objects.equals(value, that.value)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(abort,  code,  delay,  duration,  method,  mode,  patch,  path,  port,  replace,  requestHeaders,  responseHeaders,  selector,  target,  value,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (abort != null) { sb.append("abort:"); sb.append(abort + ","); }
    if (code != null) { sb.append("code:"); sb.append(code + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (method != null) { sb.append("method:"); sb.append(method + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (replace != null) { sb.append("replace:"); sb.append(replace + ","); }
    if (requestHeaders != null && !requestHeaders.isEmpty()) { sb.append("requestHeaders:"); sb.append(requestHeaders + ","); }
    if (responseHeaders != null && !responseHeaders.isEmpty()) { sb.append("responseHeaders:"); sb.append(responseHeaders + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (target != null) { sb.append("target:"); sb.append(target + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withAbort() {
    return withAbort(true);
  }
  public class PatchNested<N> extends PodHttpChaosPatchActionsFluent<PatchNested<N>> implements Nested<N>{
    PatchNested(PodHttpChaosPatchActions item) {
      this.builder = new PodHttpChaosPatchActionsBuilder(this, item);
    }
    PodHttpChaosPatchActionsBuilder builder;
    
    public N and() {
      return (N) HTTPChaosSpecFluent.this.withPatch(builder.build());
    }
    
    public N endPatch() {
      return and();
    }
    
  
  }
  public class ReplaceNested<N> extends PodHttpChaosReplaceActionsFluent<ReplaceNested<N>> implements Nested<N>{
    ReplaceNested(PodHttpChaosReplaceActions item) {
      this.builder = new PodHttpChaosReplaceActionsBuilder(this, item);
    }
    PodHttpChaosReplaceActionsBuilder builder;
    
    public N and() {
      return (N) HTTPChaosSpecFluent.this.withReplace(builder.build());
    }
    
    public N endReplace() {
      return and();
    }
    
  
  }
  public class SelectorNested<N> extends PodSelectorSpecFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodSelectorSpec item) {
      this.builder = new PodSelectorSpecBuilder(this, item);
    }
    PodSelectorSpecBuilder builder;
    
    public N and() {
      return (N) HTTPChaosSpecFluent.this.withSelector(builder.build());
    }
    
    public N endSelector() {
      return and();
    }
    
  
  }

}

==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/HTTPChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPChaosSpecFluent<A extends HTTPChaosSpecFluent<A>> extends BaseFluent<A>{
  public HTTPChaosSpecFluent() {
  }
  
  public HTTPChaosSpecFluent(HTTPChaosSpec instance) {
    this.copyInstance(instance);
  }
  private Boolean abort;
  private Integer code;
  private String delay;
  private String duration;
  private String method;
  private String mode;
  private PodHttpChaosPatchActionsBuilder patch;
  private String path;
  private Integer port;
  private PodHttpChaosReplaceActionsBuilder replace;
  private Map<String,String> requestHeaders;
  private Map<String,String> responseHeaders;
  private PodSelectorSpecBuilder selector;
  private String target;
  private String value;
  
  protected void copyInstance(HTTPChaosSpec instance) {
    instance = (instance != null ? instance : new HTTPChaosSpec());
    if (instance != null) {
          this.withAbort(instance.getAbort());
          this.withCode(instance.getCode());
          this.withDelay(instance.getDelay());
          this.withDuration(instance.getDuration());
          this.withMethod(instance.getMethod());
          this.withMode(instance.getMode());
          this.withPatch(instance.getPatch());
          this.withPath(instance.getPath());
          this.withPort(instance.getPort());
          this.withReplace(instance.getReplace());
          this.withRequestHeaders(instance.getRequestHeaders());
          this.withResponseHeaders(instance.getResponseHeaders());
          this.withSelector(instance.getSelector());
          this.withTarget(instance.getTarget());
          this.withValue(instance.getValue());
          this.withAbort(instance.getAbort());
          this.withCode(instance.getCode());
          this.withDelay(instance.getDelay());
          this.withDuration(instance.getDuration());
          this.withMethod(instance.getMethod());
          this.withMode(instance.getMode());
          this.withPatch(instance.getPatch());
          this.withPath(instance.getPath());
          this.withPort(instance.getPort());
          this.withReplace(instance.getReplace());
          this.withRequestHeaders(instance.getRequestHeaders());
          this.withResponseHeaders(instance.getResponseHeaders());
          this.withSelector(instance.getSelector());
          this.withTarget(instance.getTarget());
          this.withValue(instance.getValue());
        }
  }
  
  public Boolean getAbort() {
    return this.abort;
  }
  
  public A withAbort(Boolean abort) {
    this.abort = abort;
    return (A) this;
  }
  
  public boolean hasAbort() {
    return this.abort != null;
  }
  
  public Integer getCode() {
    return this.code;
  }
  
  public A withCode(Integer code) {
    this.code = code;
    return (A) this;
  }
  
  public boolean hasCode() {
    return this.code != null;
  }
  
  public String getDelay() {
    return this.delay;
  }
  
  public A withDelay(String delay) {
    this.delay = delay;
    return (A) this;
  }
  
  public boolean hasDelay() {
    return this.delay != null;
  }
  
  public String getDuration() {
    return this.duration;
  }
  
  public A withDuration(String duration) {
    this.duration = duration;
    return (A) this;
  }
  
  public boolean hasDuration() {
    return this.duration != null;
  }
  
  public String getMethod() {
    return this.method;
  }
  
  public A withMethod(String method) {
    this.method = method;
    return (A) this;
  }
  
  public boolean hasMethod() {
    return this.method != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode = mode;
    return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public PodHttpChaosPatchActions buildPatch() {
    return this.patch != null ? this.patch.build() : null;
  }
  
  public A withPatch(PodHttpChaosPatchActions patch) {
    this._visitables.remove(this.patch);
    if (patch != null) {
        this.patch = new PodHttpChaosPatchActionsBuilder(patch);
        this._visitables.get("patch").add(this.patch);
    } else {
        this.patch = null;
        this._visitables.get("patch").remove(this.patch);
    }
    return (A) this;
  }
  
  public boolean hasPatch() {
    return this.patch != null;
  }
  
  public PatchNested<A> withNewPatch() {
    return new PatchNested(null);
  }
  
  public PatchNested<A> withNewPatchLike(PodHttpChaosPatchActions item) {
    return new PatchNested(item);
  }
  
  public PatchNested<A> editPatch() {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(null));
  }
  
  public PatchNested<A> editOrNewPatch() {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(new PodHttpChaosPatchActionsBuilder().build()));
  }
  
  public PatchNested<A> editOrNewPatchLike(PodHttpChaosPatchActions item) {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(item));
  }
  
  public String getPath() {
    return this.path;
  }
  
  public A withPath(String path) {
    this.path = path;
    return (A) this;
  }
  
  public boolean hasPath() {
    return this.path != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port = port;
    return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public PodHttpChaosReplaceActions buildReplace() {
    return this.replace != null ? this.replace.build() : null;
  }
  
  public A withReplace(PodHttpChaosReplaceActions replace) {
    this._visitables.remove(this.replace);
    if (replace != null) {
        this.replace = new PodHttpChaosReplaceActionsBuilder(replace);
        this._visitables.get("replace").add(this.replace);
    } else {
        this.replace = null;
        this._visitables.get("replace").remove(this.replace);
    }
    return (A) this;
  }
  
  public boolean hasReplace() {
    return this.replace != null;
  }
  
  public ReplaceNested<A> withNewReplace() {
    return new ReplaceNested(null);
  }
  
  public ReplaceNested<A> withNewReplaceLike(PodHttpChaosReplaceActions item) {
    return new ReplaceNested(item);
  }
  
  public ReplaceNested<A> editReplace() {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(null));
  }
  
  public ReplaceNested<A> editOrNewReplace() {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(new PodHttpChaosReplaceActionsBuilder().build()));
  }
  
  public ReplaceNested<A> editOrNewReplaceLike(PodHttpChaosReplaceActions item) {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(item));
  }
  
  public A addToRequestHeaders(String key,String value) {
    if(this.requestHeaders == null && key != null && value != null) { this.requestHeaders = new LinkedHashMap(); }
    if(key != null && value != null) {this.requestHeaders.put(key, value);} return (A)this;
  }
  
  public A addToRequestHeaders(Map<String,String> map) {
    if(this.requestHeaders == null && map != null) { this.requestHeaders = new LinkedHashMap(); }
    if(map != null) { this.requestHeaders.putAll(map);} return (A)this;
  }
  
  public A removeFromRequestHeaders(String key) {
    if(this.requestHeaders == null) { return (A) this; }
    if(key != null && this.requestHeaders != null) {this.requestHeaders.remove(key);} return (A)this;
  }
  
  public A removeFromRequestHeaders(Map<String,String> map) {
    if(this.requestHeaders == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.requestHeaders != null){this.requestHeaders.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getRequestHeaders() {
    return this.requestHeaders;
  }
  
  public <K,V>A withRequestHeaders(Map<String,String> requestHeaders) {
    if (requestHeaders == null) {
      this.requestHeaders = null;
    } else {
      this.requestHeaders = new LinkedHashMap(requestHeaders);
    }
    return (A) this;
  }
  
  public boolean hasRequestHeaders() {
    return this.requestHeaders != null;
  }
  
  public A addToResponseHeaders(String key,String value) {
    if(this.responseHeaders == null && key != null && value != null) { this.responseHeaders = new LinkedHashMap(); }
    if(key != null && value != null) {this.responseHeaders.put(key, value);} return (A)this;
  }
  
  public A addToResponseHeaders(Map<String,String> map) {
    if(this.responseHeaders == null && map != null) { this.responseHeaders = new LinkedHashMap(); }
    if(map != null) { this.responseHeaders.putAll(map);} return (A)this;
  }
  
  public A removeFromResponseHeaders(String key) {
    if(this.responseHeaders == null) { return (A) this; }
    if(key != null && this.responseHeaders != null) {this.responseHeaders.remove(key);} return (A)this;
  }
  
  public A removeFromResponseHeaders(Map<String,String> map) {
    if(this.responseHeaders == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.responseHeaders != null){this.responseHeaders.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getResponseHeaders() {
    return this.responseHeaders;
  }
  
  public <K,V>A withResponseHeaders(Map<String,String> responseHeaders) {
    if (responseHeaders == null) {
      this.responseHeaders = null;
    } else {
      this.responseHeaders = new LinkedHashMap(responseHeaders);
    }
    return (A) this;
  }
  
  public boolean hasResponseHeaders() {
    return this.responseHeaders != null;
  }
  
  public PodSelectorSpec buildSelector() {
    return this.selector != null ? this.selector.build() : null;
  }
  
  public A withSelector(PodSelectorSpec selector) {
    this._visitables.remove(this.selector);
    if (selector != null) {
        this.selector = new PodSelectorSpecBuilder(selector);
        this._visitables.get("selector").add(this.selector);
    } else {
        this.selector = null;
        this._visitables.get("selector").remove(this.selector);
    }
    return (A) this;
  }
  
  public boolean hasSelector() {
    return this.selector != null;
  }
  
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  
  public SelectorNested<A> withNewSelectorLike(PodSelectorSpec item) {
    return new SelectorNested(item);
  }
  
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodSelectorSpecBuilder().build()));
  }
  
  public SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  
  public String getTarget() {
    return this.target;
  }
  
  public A withTarget(String target) {
    this.target = target;
    return (A) this;
  }
  
  public boolean hasTarget() {
    return this.target != null;
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value = value;
    return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPChaosSpecFluent that = (HTTPChaosSpecFluent) o;
    if (!java.util.Objects.equals(abort, that.abort)) return false;
    if (!java.util.Objects.equals(code, that.code)) return false;
    if (!java.util.Objects.equals(delay, that.delay)) return false;
    if (!java.util.Objects.equals(duration, that.duration)) return false;
    if (!java.util.Objects.equals(method, that.method)) return false;
    if (!java.util.Objects.equals(mode, that.mode)) return false;
    if (!java.util.Objects.equals(patch, that.patch)) return false;
    if (!java.util.Objects.equals(path, that.path)) return false;
    if (!java.util.Objects.equals(port, that.port)) return false;
    if (!java.util.Objects.equals(replace, that.replace)) return false;
    if (!java.util.Objects.equals(requestHeaders, that.requestHeaders)) return false;
    if (!java.util.Objects.equals(responseHeaders, that.responseHeaders)) return false;
    if (!java.util.Objects.equals(selector, that.selector)) return false;
    if (!java.util.Objects.equals(target, that.target)) return false;
    if (!java.util.Objects.equals(value, that.value)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(abort,  code,  delay,  duration,  method,  mode,  patch,  path,  port,  replace,  requestHeaders,  responseHeaders,  selector,  target,  value,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (abort != null) { sb.append("abort:"); sb.append(abort + ","); }
    if (code != null) { sb.append("code:"); sb.append(code + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (method != null) { sb.append("method:"); sb.append(method + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (replace != null) { sb.append("replace:"); sb.append(replace + ","); }
    if (requestHeaders != null && !requestHeaders.isEmpty()) { sb.append("requestHeaders:"); sb.append(requestHeaders + ","); }
    if (responseHeaders != null && !responseHeaders.isEmpty()) { sb.append("responseHeaders:"); sb.append(responseHeaders + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (target != null) { sb.append("target:"); sb.append(target + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withAbort() {
    return withAbort(true);
  }
  public class PatchNested<N> extends PodHttpChaosPatchActionsFluent<PatchNested<N>> implements Nested<N>{
    PatchNested(PodHttpChaosPatchActions item) {
      this.builder = new PodHttpChaosPatchActionsBuilder(this, item);
    }
    PodHttpChaosPatchActionsBuilder builder;
    
    public N and() {
      return (N) HTTPChaosSpecFluent.this.withPatch(builder.build());
    }
    
    public N endPatch() {
      return and();
    }
    
  
  }
  public class ReplaceNested<N> extends PodHttpChaosReplaceActionsFluent<ReplaceNested<N>> implements Nested<N>{
    ReplaceNested(PodHttpChaosReplaceActions item) {
      this.builder = new PodHttpChaosReplaceActionsBuilder(this, item);
    }
    PodHttpChaosReplaceActionsBuilder builder;
    
    public N and() {
      return (N) HTTPChaosSpecFluent.this.withReplace(builder.build());
    }
    
    public N endReplace() {
      return and();
    }
    
  
  }
  public class SelectorNested<N> extends PodSelectorSpecFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodSelectorSpec item) {
      this.builder = new PodSelectorSpecBuilder(this, item);
    }
    PodSelectorSpecBuilder builder;
    
    public N and() {
      return (N) HTTPChaosSpecFluent.this.withSelector(builder.build());
    }
    
    public N endSelector() {
      return and();
    }
    
  
  }

}
